@@ -1188,11 +1188,11 @@ class Date(Time):
             _Y_     -> 1985
 
             _MM_    -> 06       [force has 2 characters]
-            _NM_    -> {_DICTIONARY[self._language]['June']}
+            _NM_    -> {_DICTIONARY[self._language]['june']}
             _M_     -> 6
 
             _DD_    -> 21       [force has 2 characters]
-            _ND_    -> {_DICTIONARY[self._language]['Friday']}
+            _ND_    -> {_DICTIONARY[self._language]['friday']}
             _D_     -> 21
 
             _hh_    -> 11       [force has 2 characters]
